==> moodle-3.4.4.zip: moodle/lang/en/tag.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'tag', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   core_tag
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['added'] = 'Standard tag(s) added';
$string['addotags'] = 'Add standard tags';
$string['addtagcoll'] = 'Add tag collection';
$string['addtagtomyinterests'] = 'Add "{$a}" to my interests';
$string['alltagpages'] = 'All tag pages';
$string['backtoallitems'] = 'Back to all items tagged with "{$a}"';
$string['changeshowstandard'] = 'Change showing standard tags in area {$a}';
$string['changessaved'] = 'Changes saved';
$string['changetagcoll'] = 'Change tag collection of area {$a}';
$string['collnameexplained'] = 'Leave the field empty to use the default value: {$a}';
$string['component'] = 'Component';
$string['confirmdeletetag'] = 'Are you sure you want to delete this tag?';
$string['confirmdeletetags'] = 'Are you sure you want to delete selected tags?';
$string['count'] = 'Count';
$string['coursetags'] = 'Course tags';
$string['defautltagcoll'] = 'Default collection';
$string['delete'] = 'Delete';
$string['deleteselected'] = 'Delete selected';
$string['deleted'] = 'Tag(s) deleted';
$string['deletedcoursetags'] = 'Deleted - Course tags';
$string['description'] = 'Description';
$string['editisstandard'] = 'Change standard tag usage';
$string['editcollname'] = 'Edit tag collection name';
$string['editname'] = 'Edit tag name';
$string['editsearchable'] = 'Change searchable';
$string['edittag'] = 'Edit this tag';
$string['edittagcollection'] = 'Change tag collection';
$string['entertags'] = 'Enter tags...';
$string['edittagcoll'] = 'Edit tag collection {$a}';
$string['errortagfrontpage'] = 'Tagging the site main page is not allowed';
$string['errorupdatingrecord'] = 'Error updating tag record';
$string['eventtagadded'] = 'Tag added to an item';
$string['eventtagcolldeleted'] = 'Tag collection deleted';
$string['eventtagcollcreated'] = 'Tag collection created';
$string['eventtagcollupdated'] = 'Tag collection updated';
$string['eventtagcreated'] = 'Tag created';
$string['eventtagdeleted'] = 'Tag deleted';
$string['eventtagflagged'] = 'Tag flagged';
$string['eventtagremoved'] = 'Tag removed from an item';
$string['eventtagunflagged'] = 'Tag unflagged';
$string['eventtagupdated'] = 'Tag updated';
$string['exclusivemode'] = 'Show only tagged {$a->tagarea}';
$string['flag'] = 'Flag';
$string['flagged'] = 'Tag flagged';
$string['flagasinappropriate'] = 'Flag as inappropriate';
$string['helprelatedtags'] = 'Comma separated related tags';
$string['changename'] = 'Change tag name';
$string['changetype'] = 'Change tag type';
$string['combined'] = 'Tags are combined';
$string['combineselected'] = 'Combine selected';
$string['id'] = 'id';
$string['inalltagcoll'] = 'Everywhere';
$string['inputstandardtags'] = 'Enter comma-separated list of new tags';
$string['itemstaggedwith'] = '{$a->tagarea} tagged with "{$a->tag}"';
$string['lesstags'] = 'less...';
$string['managestandardtags'] = 'Manage standard tags';
$string['managetags'] = 'Manage tags';
$string['managetagcolls'] = 'Manage tag collections';
$string['moretags'] = 'more...';
$string['name'] = 'Tag name';
$string['namesalreadybeeingused'] = 'Tag names already being used';
$string['nameuseddocombine'] = 'The tag name is already in use. Do you want to combine these tags?';
$string['newcollnamefor'] = 'New name for tag collection {$a}';
$string['newnamefor'] = 'New name for tag {$a}';
$string['nextpage'] = 'More';
$string['notagsfound'] = 'No tags matching "{$a}" found';
$string['noresultsfor'] = 'No results for "{$a}"';
$string['nothingtoupdate'] = 'Nothing to update';
$string['owner'] = 'Owner';
$string['prevpage'] = 'Back';
$string['privacy:metadata:tag'] = 'The details of each unique tag are stored alongside their description and other related information';
$string['privacy:metadata:tag:name'] = 'The name of the tag - this is the normalised version of the name.';
$string['privacy:metadata:tag:rawname'] = 'The name of the tag - this is the display name.';
$string['privacy:metadata:tag:description'] = 'The description of the tag.';
$string['privacy:metadata:tag:flag'] = 'Whether a tag has been flagged as inappropriate.';
$string['privacy:metadata:tag:timemodified'] = 'The time that the tag was last modified.';
$string['privacy:metadata:tag:userid'] = 'The ID of the user who created the tag.';
$string['privacy:metadata:taginstance'] = 'The link between each tag and where it is used.';
$string['privacy:metadata:taginstance:tagid'] = 'The link to the tag.';
$string['privacy:metadata:taginstance:ordering'] = 'The relative order of this tag.';
$string['privacy:metadata:taginstance:timecreated'] = 'The time that this tag was linked to the target.';
$string['privacy:metadata:taginstance:timemodified'] = 'The time that this tag was modified for the target.';
$string['privacy:metadata:taginstance:tiuserid'] = 'Where shared content can be individually tagged by users, the owner of the tag instance is stored.';
$string['ptags'] = 'User defined tags (Comma separated)';
$string['relatedblogs'] = 'Most recent blog entries';
$string['relatedtags'] = 'Related tags';
$string['removetagfrommyinterests'] = 'Remove "{$a}" from my interests';
$string['reset'] = 'Tag flag reset';
$string['resetfilter'] = 'Reset filter';
$string['resetflag'] = 'Reset flag';
$string['responsiblewillbenotified'] = 'The person responsible will be notified';
$string['rssdesc'] = 'This RSS feed was automatically generated by Moodle and contains user generated tags for courses.';
$string['rsstitle'] = 'Course tags RSS feed for user: {$a}';
$string['showstandard'] = 'Standard tags usage';
$string['showstandard_help'] = 'When entering tags, standard tags may be suggested, or forced, meaning that new tags cannot be entered. Alternatively, new tags may be entered with no standard tag being suggested.';
$string['search'] = 'Search';
$string['searchable'] = 'Searchable';
$string['searchable_help'] = 'If ticked, tags in this search collection can be found via the "Search tags" page. If unticked, tags can still be found via other search pages.';
$string['searchresultsfor'] = 'Search results for "{$a}"';
$string['searchtags'] = 'Search tags';
$string['seeallblogs'] = 'See all blog entries tagged with "{$a}"';
$string['select'] = 'Select';
$string['selectcoll'] = 'Select tag collection';
$string['selectmaintag'] = 'Select the tag that will be used after combining';
$string['selectmultipletags'] = 'Please select more than one tag';
$string['selecttag'] = 'Select tag {$a}';
$string['settypedefault'] = 'Remove from standard tags';
$string['settypestandard'] = 'Make standard';
$string['showingfirsttags'] = 'Showing {$a} most popular tags';
$string['standardforce'] = 'Force';
$string['standardhide'] = 'Don\'t suggest';
$string['standardsuggest'] = 'Suggest';
$string['standardtag'] = 'Standard';
$string['suredeletecoll'] = 'Are you sure you want to delete tag collection "{$a}"?';
$string['tag'] = 'Tag';
$string['tagarea_blog_external'] = 'External blog posts';
$string['tagarea_post'] = 'Blog posts';
$string['tagarea_user'] = 'User interests';
$string['tagarea_course'] = 'Courses';
$string['tagarea_course_modules'] = 'Activities and resources';
$string['tagareaenabled'] = 'Enabled';
$string['tagareaname'] = 'Name';
$string['tagareas'] = 'Tag areas';
$string['tagcollection'] = 'Tag collection';
$string['tagcollection_help'] = 'Tag collections are sets of tags for different areas. For example, a collection of standard tags can be used to tag courses, with user interests and blog post tags kept in a separate collection. When a user clicks on a tag, the tag page displays only items with that tag in the same collection. Tags can be automatically added to a collection according to the area tagged or can be added manually as standard tags.';
$string['tagcollections'] = 'Tag collections';
$string['tagdescription'] = 'Tag description';
$string['tags'] = 'Tags';
$string['tagsaredisabled'] = 'Tags are disabled';
$string['thingstaggedwith'] = '"{$a->name}" is used {$a->count} times';
$string['thingtaggedwith'] = '"{$a->name}" is used once';
$string['timemodified'] = 'Modified';
$string['typechanged'] = 'Tag type changed';
$string['updatetag'] = 'Update';
$string['page-tag-x'] = 'All tag pages';
$string['page-tag-index'] = 'Single tag page';
$string['page-tag-search'] = 'Tag search page';
$string['page-tag-manage'] = 'Manage tags page';

// Deprecated since 3.1 .

$string['manageofficialtags'] = 'Manage official tags';
$string['officialtag'] = 'Official';
$string['otags'] = 'Official tags';
$string['othertags'] = 'Other tags';
$string['settypeofficial'] = 'Make official';
$string['taggedwith'] = 'tagged with "{$a}"';
$string['tagtype'] = 'Tag type';

==> moodle-4.5.4.zip: moodle/lang/en/tag.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'tag', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   core_tag
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['added'] = 'Standard tag(s) added';
$string['addotags'] = 'Add standard tags';
$string['addtagcoll'] = 'Add tag collection';
$string['addtagtomyinterests'] = 'Add "{$a}" to my interests';
$string['alltagpages'] = 'All tag pages';
$string['backtoallitems'] = 'Back to all items tagged with "{$a}"';
$string['changeshowstandard'] = 'Change showing standard tags in area {$a}';
$string['changessaved'] = 'Changes saved';
$string['changetagcoll'] = 'Change tag collection of area {$a}';
$string['collnameexplained'] = 'Leave the field empty to use the default value: {$a}';
$string['component'] = 'Component';
$string['confirmdeletetag'] = 'Are you sure you want to delete this tag?';
$string['confirmdeletetags'] = 'Are you sure you want to delete selected tags?';
$string['count'] = 'Count';
$string['coursetags'] = 'Course tags';
$string['defautltagcoll'] = 'Default collection';
$string['delete'] = 'Delete';
$string['deleteselected'] = 'Delete selected';
$string['deleted'] = 'Tag(s) deleted';
$string['deletedcoursetags'] = 'Deleted - Course tags';
$string['description'] = 'Description';
$string['editisstandard'] = 'Change standard tag usage';
$string['editcollname'] = 'Edit tag collection name';
$string['editname'] = 'Edit tag name';
$string['editsearchable'] = 'Change searchable';
$string['edittag'] = 'Edit this tag';
$string['edittagcollection'] = 'Change tag collection';
$string['entertags'] = 'Enter tags...';
$string['edittagcoll'] = 'Edit tag collection {$a}';
$string['errortagfrontpage'] = 'Tagging the site main page is not allowed';
$string['errorupdatingrecord'] = 'Error updating tag record';
$string['eventtagadded'] = 'Tag added to an item';
$string['eventtagcolldeleted'] = 'Tag collection deleted';
$string['eventtagcollcreated'] = 'Tag collection created';
$string['eventtagcollupdated'] = 'Tag collection updated';
$string['eventtagcreated'] = 'Tag created';
$string['eventtagdeleted'] = 'Tag deleted';
$string['eventtagflagged'] = 'Tag flagged';
$string['eventtagremoved'] = 'Tag removed from an item';
$string['eventtagunflagged'] = 'Tag unflagged';
$string['eventtagupdated'] = 'Tag updated';
$string['exclusivemode'] = 'Show only tagged {$a->tagarea}';
$string['flag'] = 'Flag';
$string['flagcount'] = 'Flag count';
$string['flagged'] = 'Tag flagged';
$string['flagasinappropriate'] = 'Flag as inappropriate';
$string['helprelatedtags'] = 'Comma separated related tags';
$string['changename'] = 'Change tag name';
$string['changetype'] = 'Change tag type';
$string['combined'] = 'Tags are combined';
$string['combineselected'] = 'Combine selected';
$string['id'] = 'id';
$string['inalltagcoll'] = 'Everywhere';
$string['inputstandardtags'] = 'Enter comma-separated list of new tags';
$string['itemid'] = 'Item ID';
$string['itemstaggedwith'] = '{$a->tagarea} tagged with "{$a->tag}"';
$string['itemtype'] = 'Item type';
$string['lesstags'] = 'less...';
$string['managestandardtags'] = 'Manage standard tags';
$string['managetags'] = 'Manage tags';
$string['managetagcolls'] = 'Manage tag collections';
$string['moretags'] = 'more...';
$string['name'] = 'Tag name';
$string['namesalreadybeeingused'] = 'Tag names already being used';
$string['nameuseddocombine'] = 'The tag name is already in use. Do you want to combine these tags?';
$string['namewithlink'] = 'Tag name with link';
$string['newcollnamefor'] = 'New name for tag collection {$a}';
$string['newnamefor'] = 'New name for tag {$a}';
$string['nextpage'] = 'More';
$string['notagsfound'] = 'No tags matching "{$a}" found';
$string['noresultsfor'] = 'No results for "{$a}"';
$string['nothingtoupdate'] = 'Nothing to update';
$string['owner'] = 'Owner';
$string['prevpage'] = 'Back';
$string['privacy:metadata:tag'] = 'The details of each unique tag are stored alongside their description and other related information';
$string['privacy:metadata:tag:name'] = 'The name of the tag - this is the normalised version of the name.';
$string['privacy:metadata:tag:rawname'] = 'The name of the tag - this is the display name.';
$string['privacy:metadata:tag:description'] = 'The description of the tag.';
$string['privacy:metadata:tag:flag'] = 'Whether a tag has been flagged as inappropriate.';
$string['privacy:metadata:tag:timemodified'] = 'The time that the tag was last modified.';
$string['privacy:metadata:tag:userid'] = 'The ID of the user who created the tag.';
$string['privacy:metadata:taginstance'] = 'The link between each tag and where it is used.';
$string['privacy:metadata:taginstance:tagid'] = 'The link to the tag.';
$string['privacy:metadata:taginstance:ordering'] = 'The relative order of this tag.';
$string['privacy:metadata:taginstance:timecreated'] = 'The time that this tag was linked to the target.';
$string['privacy:metadata:taginstance:timemodified'] = 'The time that this tag was modified for the target.';
$string['privacy:metadata:taginstance:tiuserid'] = 'Where shared content can be individually tagged by users, the owner of the tag instance is stored.';
$string['ptags'] = 'User defined tags (Comma separated)';
$string['relatedblogs'] = 'Most recent blog entries';
$string['relatedtags'] = 'Related tags';
$string['removetagfrommyinterests'] = 'Remove "{$a}" from my interests';
$string['reset'] = 'Tag flag reset';
$string['resetfilter'] = 'Reset filter';
$string['resetflag'] = 'Reset flag';
$string['responsiblewillbenotified'] = 'The person responsible will be notified';
$string['rssdesc'] = 'This RSS feed was automatically generated by Moodle and contains user generated tags for courses.';
$string['rsstitle'] = 'Course tags RSS feed for user: {$a}';
$string['showstandard'] = 'Standard tags usage';
$string['showstandard_help'] = 'When entering tags, standard tags may be suggested, or forced, meaning that new tags cannot be entered. Alternatively, new tags may be entered with no standard tag being suggested.';
$string['search'] = 'Search';
$string['searchable'] = 'Searchable';
$string['searchable_help'] = 'If ticked, tags in this search collection can be found via the "Search tags" page. If unticked, tags can still be found via other search pages.';
$string['searchresultsfor'] = 'Search results for "{$a}"';
$string['searchtags'] = 'Search tags';
$string['seeallblogs'] = 'See all blog entries tagged with "{$a}"';
$string['select'] = 'Select';
$string['selectcoll'] = 'Select tag collection';
$string['selectmaintag'] = 'Select the tag that will be used after combining';
$string['selectmultipletags'] = 'Please select more than one tag';
$string['selecttag'] = 'Select tag {$a}';
$string['settypedefault'] = 'Remove from standard tags';
$string['settypestandard'] = 'Make standard';
$string['showingfirsttags'] = 'Showing {$a} most popular tags';
$string['standardforce'] = 'Force';
$string['standardhide'] = 'Don\'t suggest';
$string['standardsuggest'] = 'Suggest';
$string['standardtag'] = 'Standard';
$string['suredeletecoll'] = 'Are you sure you want to delete tag collection "{$a}"?';
$string['tag'] = 'Tag';
$string['tagarea'] = 'Tag area';
$string['tagarea_blog_external'] = 'External blog posts';
$string['tagarea_post'] = 'Blog posts';
$string['tagarea_user'] = 'User interests';
$string['tagarea_course'] = 'Courses';
$string['tagarea_course_modules'] = 'Activities and resources';
$string['tagarea_tag'] = 'Related tags';
$string['tagareaenabled'] = 'Enabled';
$string['tagareaname'] = 'Name';
$string['tagareas'] = 'Tag areas';
$string['tagauthor'] = 'Tag author';
$string['tagcollection'] = 'Tag collection';
$string['tagcollection_help'] = 'Tag collections are sets of tags for different areas. For example, a collection of standard tags can be used to tag courses, with user interests and blog post tags kept in a separate collection. When a user clicks on a tag, the tag page displays only items with that tag in the same collection. Tags can be automatically added to a collection according to the area tagged or can be added manually as standard tags.';
$string['tagcollections'] = 'Tag collections';
$string['tagdescription'] = 'Tag description';
$string['taginstance'] = 'Tag instance';
$string['tags'] = 'Tags';
$string['tagsaredisabled'] = 'Tags are disabled';
$string['thingstaggedwith'] = '"{$a->name}" is used {$a->count} times';
$string['thingtaggedwith'] = '"{$a->name}" is used once';
$string['timemodified'] = 'Modified';
$string['typechanged'] = 'Tag type changed';
$string['updatetag'] = 'Update';
$string['page-tag-x'] = 'All tag pages';
$string['page-tag-index'] = 'Single tag page';
$string['page-tag-search'] = 'Tag search page';
$string['page-tag-manage'] = 'Manage tags page';
